==> bottom-1.0.0.tar.gz: bottom-1.0.0/setup.py <==
""" Setup file """
import os
from setuptools import setup, find_packages

HERE = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(HERE, 'README.rst')).read()


def get_version():
    with open("bottom/__init__.py") as f:
        for line in f:
            if line.startswith("__version__"):
                return eval(line.split("=")[-1])

REQUIREMENTS = [
    'simplex'
]

TEST_REQUIREMENTS = [
    'alabaster',
    'coverage',
    'flake8',
    'pytest',
    'sphinx',
    'tox',
]

if __name__ == "__main__":
    setup(
        name='bottom',
        version=get_version(),
        description="asyncio-based rfc2812-compliant IRC Client",
        long_description=README,
        classifiers=[
            'Development Status :: 4 - Beta',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: MIT License',
            'Operating System :: OS Independent',
            'Programming Language :: Python',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.4',
            'Topic :: Software Development :: Libraries',
            'Topic :: Communications :: Chat',
            'Topic :: Communications :: Chat :: Internet Relay Chat'
        ],
        author='Joe Cross',
        author_email='joe.mcross@gmail.com',
        url='https://github.com/numberoverzero/bottom',
        license='MIT',
        keywords='irc bot asnycio client',
        platforms='any',
        include_package_data=True,
        packages=find_packages(exclude=('tests', 'examples')),
        install_requires=REQUIREMENTS,
        tests_require=REQUIREMENTS + TEST_REQUIREMENTS,
    )

==> bottom-2.0.0.tar.gz: bottom-2.0.0/setup.py <==
""" Setup file """
import os
from setuptools import setup, find_packages

HERE = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(HERE, 'README.rst')).read()


def get_version():
    with open("bottom/__init__.py") as f:
        for line in f:
            if line.startswith("__version__"):
                return eval(line.split("=")[-1])

REQUIREMENTS = []

TEST_REQUIREMENTS = [
    'coverage',
    'flake8',
    'mypy',
    'pytest',
    'tox',
]

if __name__ == "__main__":
    setup(
        name='bottom',
        version=get_version(),
        description="asyncio-based rfc2812-compliant IRC Client",
        long_description=README,
        classifiers=[
            'Development Status :: 4 - Beta',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: MIT License',
            'Operating System :: OS Independent',
            'Programming Language :: Python',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.4',
            'Topic :: Software Development :: Libraries',
            'Topic :: Communications :: Chat',
            'Topic :: Communications :: Chat :: Internet Relay Chat'
        ],
        author='Joe Cross',
        author_email='joe.mcross@gmail.com',
        url='https://github.com/numberoverzero/bottom',
        license='MIT',
        keywords='irc bot asyncio client',
        platforms='any',
        include_package_data=True,
        packages=find_packages(exclude=('tests', 'examples')),
        install_requires=REQUIREMENTS,
        tests_require=REQUIREMENTS + TEST_REQUIREMENTS,
    )
